# eric7.EricXML.Config

Module implementing some common configuration stuf for the XML package.

### Global Attributes

debuggerPropertiesFileFormatVersion
dictionariesListFileFormatVersion
highlightingStylesFileFormatVersion
multiProjectFileFormatVersion
pluginRepositoryFileFormatVersion
projectFileFormatVersion
projectFileFormatVersionAlt
projectFileFormatVersionIdl
projectFileFormatVersionMake
projectFileFormatVersionProto
projectFileFormatVersionRcc
projectFileFormatVersionUic
sessionFileFormatVersion
shortcutsFileFormatVersion
tasksFileFormatVersion
templatesFileFormatVersion
userProjectFileFormatVersion

### Classes

None

### Functions

None